/*******************************************************************************
 * Copyright (c) 2010 Actuate Corporation.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *  Actuate Corporation  - initial API and implementation
 *******************************************************************************/

package org.eclipse.birt.report.data.oda.csv.ui.wizards;

import java.io.File;
import java.util.Properties;

import org.eclipse.birt.report.data.oda.csv.impl.CommonConstants;
import org.eclipse.birt.report.data.oda.csv.ui.i18n.Messages;
import org.eclipse.jface.dialogs.IMessageProvider;
import org.eclipse.jface.preference.PreferencePage;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

public class CSVFileSelectionPageHelper
{
    private WizardPage m_wizardPage;
    private PreferencePage m_propertyPage;

    private transient Text fileName = null;
    
    static final String DEFAULT_MESSAGE = 
    	Messages.getString("wizard.defaultMessage.selectFile"); //$NON-NLS-1$
    
    private static final int ERROR_FOLDER = 1;
    private static final int ERROR_EMPTY_PATH = 2;
    private static final String EMPTY_STRING = ""; //$NON-NLS-1$
    
    CSVFileSelectionPageHelper( WizardPage page )
    {
        m_wizardPage = page;
    }

    CSVFileSelectionPageHelper( PreferencePage page )
    {
        m_propertyPage = page;
    }

    void createCustomControl( Composite parent )
    {
        Composite content = new Composite( parent, SWT.NULL );
        GridLayout layout = new GridLayout( 2, false );
        content.setLayout(layout);
        
        //GridData data;
        setupFileLocation( content );
     }
    
    String getFolderLocation()
    {
        if( fileName == null )
            return EMPTY_STRING;
        return fileName.getText();
    }

    Properties collectCustomProperties( Properties props )
    {
        if( props == null )
            props = new Properties();
        
        // set custom driver specific properties
        props.setProperty( CommonConstants.CONN_HOME_DIR_PROP, 
                            getFolderLocation() );
        return props;
    }
    
    void initCustomControl( Properties profileProps )
    {
        if( profileProps == null || profileProps.isEmpty() || 
        		fileName == null )
            return;     // nothing to initialize
        
        String folderPath = profileProps.getProperty( CommonConstants.CONN_HOME_DIR_PROP );
        if( folderPath == null )
            folderPath = EMPTY_STRING;
        fileName.setText( folderPath );

        verifyFileLocation();
    }

    private void setupFileLocation( Composite composite )
    {
        Label label = new Label( composite, SWT.NONE );
        label.setText( Messages.getString( "label.selectFile" ) ); //$NON-NLS-1$

        GridData data = new GridData( GridData.FILL_HORIZONTAL );

        fileName = new Text( composite, SWT.BORDER );
        fileName.setLayoutData( data );
        setPageComplete( false );
        fileName.addModifyListener( 
            new ModifyListener()
            {    
                public void modifyText( ModifyEvent e )
                {
                    verifyFileLocation();
                }
    
            } );
    }

    private int verifyFileLocation()
    {
		int result = 0;
		if(fileName.getText().trim().length() > 0)
        {
			File file = new File(fileName.getText().trim());
			if (file.exists() && file.isFile())
			{
				setPageComplete(true);
	            setMessage(DEFAULT_MESSAGE, IMessageProvider.NONE);				
			}
			else
			{
				setMessage(Messages.getString("error.enterfilename"), IMessageProvider.ERROR); //$NON-NLS-1$
	            setPageComplete(false);
	            result = ERROR_FOLDER; 
		     }
		     
        }
        else
        {
            setPageComplete(false);
            setMessage(Messages.getString("error.emptyPath"), IMessageProvider.ERROR); //$NON-NLS-1$
            result = ERROR_EMPTY_PATH;
        }
		return result;
    }


    private void setPageComplete( boolean complete )
    {
        if( m_wizardPage != null )
            m_wizardPage.setPageComplete( complete );
        else if( m_propertyPage != null )
            m_propertyPage.setValid( complete );
    }
    
    private void setMessage( String newMessage, int newType )
    {
        if( m_wizardPage != null )
            m_wizardPage.setMessage( newMessage, newType );
        else if( m_propertyPage != null )
            m_propertyPage.setMessage( newMessage, newType );
    }
}
